def help_lineshelp_label
   'Իٱ'
end

def help_wordshelp_label
   'ʸٱ'
end

def help_tablehelp_label
   'ɽٱ'
end

def help_pluginhelp_label
   'ץ饰ٱ'
end

def help_mathhelp_label
   'ٱ'
end

def help_heading_label
   'Ф'
end

def help_list_label
   'վ'
end

def help_numbered_label
   'ֹ'
end

def help_preformatted_label
   ''
end

def help_quotation_label
   ''
end

def help_comment_label
   ''
end

def help_cancel_label
   ''
end

def help_link_label
   ''
end

def help_url_label
   'URL'
end

def help_emphasized_label
   'Ĵ'
end

def help_strongly_label
   ''
end

def help_struckout_label
   ''
end

def help_definition_label
   'Ѹ'
end

def help_horizontal_label
   'ʿ'
end

def help_cell_label
   ''
end

def help_headingcell_label
   'Ф'
end

def help_rows_label
   'Ϣ'
end

def help_columns_label
   'Ϣ'
end

def help_plugin_label
   'ץ饰'
end

def help_br_label
   ''
end

def help_toc_label
   'ܼ'
end

def help_tochere_label
   ''
end

def help_recent_label
   'Ƕ'
end

def help_display_label
   'ǥץ쥤'
end

def help_inline_label
   '饤'
end
